/* need.c */
/* Copyright 1995 by Steve Kirkendall */

char id_need[] = "$Id: need.c,v 2.0 1996/01/03 20:20:04 steve Exp $";

#include "elvis.h"


#ifdef NEED_STRDUP
char *strdup(str)
	char	*str;
{
	char	*ret;

	ret = (char *)safealloc(strlen(str) + 1, sizeof(char));
	strcpy(ret, str);
	return ret;
}
#endif
